@@ -2,7 +2,8 @@
 ### Assume gbd.major = 1.
 
 comm.balance.info <- function(X.gbd,
-    balance.method = .SPMD.IO$balance.method[1], comm = .SPMD.CT$comm){
+    balance.method = .pbd_env$SPMD.IO$balance.method[1],
+    comm = .pbd_env$SPMD.CT$comm){
   ### Check gbd.
   if(!comm.allcommon.integer(length(dim(X.gbd)), comm = comm)){
     comm.stop("Dimension of X.gbd should all equal to 2.", comm = comm)
@@ -62,7 +63,8 @@ comm.balance.info <- function(X.gbd,
 
 
 comm.load.balance <- function(X.gbd, bal.info = NULL,
-    balance.method = .SPMD.IO$balance.method, comm = .SPMD.CT$comm){
+    balance.method = .pbd_env$SPMD.IO$balance.method[1],
+    comm = .pbd_env$SPMD.CT$comm){
   ### Check.
   if(!comm.allcommon.integer(length(dim(X.gbd)), comm = comm)){
     comm.stop("Dimension of X.gbd should all equal to 2.", comm = comm)
@@ -117,7 +119,8 @@ comm.load.balance <- function(X.gbd, bal.info = NULL,
 } # End of comm.load.balance().
 
 
-comm.unload.balance <- function(new.X.gbd, bal.info, comm = .SPMD.CT$comm){
+comm.unload.balance <- function(new.X.gbd, bal.info,
+    comm = .pbd_env$SPMD.CT$comm){
   rev.bal.info <- list(send = data.frame(org = bal.info$recv$belong,
                                          belong = bal.info$recv$org),
                        recv = data.frame(org = bal.info$send$belong,
