@@ -3,24 +3,15 @@
 ### Default method.
 spmd.allreduce.default <- function(x, x.buffer = NULL,
     op = .pbd_env$SPMD.CT$op, comm = .pbd_env$SPMD.CT$comm){
-  op <- match.arg(tolower(op[1]), .pbd_env$SPMD.OP)
-
-  if(op %in% c("land", "band", "lor", "bor", "lxor", "bxor")){
-    x <- as.integer(x)
-    if(!is.null(x.buffer)){
-      x.buffer <- as.integer(x.buffer)
-    }
-  }
-
+  comm <- as.integer(comm)
   all.array <- spmd.allreduce.integer(
                    as.integer(is.array(x) && length(x) > 0),
                    integer(1), op = "sum",
                    comm = comm) == spmd.comm.size(comm)
   if(all.array){
-    x <- spmd.allcheck.type(x, comm = comm)
-    spmd.allreduce.array(x, op = op[1], comm = comm)
+    spmd.allreduce.array(x, op = op, comm = comm)
   } else{
-    spmd.allreduce.object(x, op = op[1], comm = comm)
+    spmd.allreduce.object(x, op = op, comm = comm)
   }
 } # End of spmd.allreduce.default().
 
@@ -40,6 +31,14 @@ spmd.allreduce.double <- function(x, x.buffer,
         PACKAGE = "pbdMPI")
 } # End of spmd.allreduce.double().
 
+spmd.allreduce.logical <- function(x, x.buffer,
+    op = .pbd_env$SPMD.CT$op, comm = .pbd_env$SPMD.CT$comm){
+  ret <- .Call("spmd_allreduce_integer", x, x.buffer,
+               which(op[1] == .pbd_env$SPMD.OP), as.integer(comm),
+               PACKAGE = "pbdMPI")
+  as.logical(ret)
+} # End of spmd.allreduce.logical().
+
 
 ### S4 methods.
 setGeneric(
@@ -63,4 +62,9 @@ setMethod(
   signature = signature(x = "numeric", x.buffer = "numeric"),
   definition = spmd.allreduce.double
 )
+setMethod(
+  f = "allreduce",
+  signature = signature(x = "logical", x.buffer = "logical"),
+  definition = spmd.allreduce.logical
+)
 
